"""
create_time: 2023/2/4 15:04
author: TsangHans
"""
from unittest import TestCase
from ddtcv import Wind, save_wind_image
import cv2 as cv


class Test(TestCase):
    def test_wind(self):
        x = cv.imread("image/img2.png")
        res = Wind(x)
        assert res == 0.4

    def test_save_wind_image(self):
        x = cv.imread("image/img2.png")
        save_wind_image("image/img2_wind.png", x)



"""
create_time: 2023/2/4 14:01
author: TsangHans
"""
import os
import ddtcv
import cv2 as cv
import numpy as np

from ddtcv.onnx import ONNXModel

_static_dir = os.path.join(ddtcv.__path__[0], "static")
_default_onnx_model_fp = os.path.join(_static_dir, "model/wind_1_rec_en_number_lite/wind_1_rec_en_number_lite.onnx")
_default_character_dict_fp = os.path.join(_static_dir, "model/wind_1_rec_en_number_lite/wind_dict.txt")
_default_wind_rec_model = ONNXModel(_default_onnx_model_fp, _default_character_dict_fp)
default_x_slice = slice(17, 48)
default_y_slice = slice(461, 537)


def Wind(image: np.ndarray, rec_model: ONNXModel = _default_wind_rec_model, x_slice: slice = default_x_slice,
         y_slice: slice = default_y_slice) -> float:
    x = image[x_slice, y_slice]
    res = rec_model.predict(x)
    return float(res)


def rec_wind(wind_image: np.ndarray, rec_model: ONNXModel = _default_wind_rec_model) -> float:
    return float(rec_model.predict(wind_image))


def save_wind_image(filename: str, image: np.ndarray, x_slice: slice = default_x_slice,
                    y_slice: slice = default_y_slice) -> None:
    cv.imwrite(filename, image[x_slice, y_slice])



"""
create_time: 2023/2/4 14:24
author: TsangHans
"""
from unittest import TestCase
from ddtcv.onnx import ONNXModel
import cv2 as cv


class TestONNXModel(TestCase):
    def test_predict(self):
        m_fp = "../static/model/angle_1_rec_en_number_lite/angle_1_rec_en_number_lite.onnx"
        d_fp = "../static/model/angle_1_rec_en_number_lite/angle_dict.txt"
        m = ONNXModel(m_fp, d_fp)
        img = cv.imread("image/img.png")
        res = m.predict(img)
        assert res == "-18"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ddtcv', 'ddtcv.tests', 'ddtcv.tools']

package_data = \
{'': ['*'],
 'ddtcv': ['static/model/angle_1_rec_en_number_lite/*',
           'static/model/wind_1_rec_en_number_lite/*'],
 'ddtcv.tests': ['image/*']}

install_requires = \
['numpy>=1.21.6,<2.0.0',
 'onnxruntime>=1.13.1,<2.0.0',
 'opencv-python>=4.4.0.46,<5.0.0.0']

setup_kwargs = {
    'name': 'ddtcv',
    'version': '0.1.3',
    'description': 'DDT CV.',
    'long_description': 'Examples are as follows.\n```python\nimport ddtcv\n\nwind_value = ddtcv.Wind("your_image_array")\nangle_value = ddtcv.Angle("your_image_array")\n```\nThat\'s all.',
    'author': 'TsangHans',
    'author_email': 'gzzenghan@189.cn',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""
create_time: 2023/2/4 14:21
author: TsangHans
"""

import numpy as np

from ddtcv.abstract import CVModel
from ddtcv.tools.load_model import load_onnx
from ddtcv.tools.preprocess import build_preprocess
from ddtcv.tools.postprocess import build_postprocess


class ONNXModel(CVModel):
    def __init__(self, onnx_model_fp, character_dict_fp, preprocess_method="CTC"):
        self._preprocess_func = build_preprocess(preprocess_method)
        self._session = load_onnx(onnx_model_fp)
        self._postprocess_func = build_postprocess(character_dict_fp)

    def predict(self, image: np.ndarray):
        d_height, d_width, d_channel = image.shape
        input_image_shape = (d_channel, d_height, d_width)  # 模型的输入维度：通道数 * 高度 * 宽度
        norm_image = self._preprocess_func(image, input_image_shape)  # 进行数据预处理

        # 使用模型对预处理数据进行运算
        input_name = self._session.get_inputs()[0].name
        output = self._session.run([], {input_name: norm_image})

        # 将模型的输出进行后处理，得到识别结果
        res = self._postprocess_func(output)[0][0]
        return res




"""
create_time: 2023/2/4 14:03
author: TsangHans
"""
import os
import ddtcv
import cv2 as cv
import numpy as np

from ddtcv.onnx import ONNXModel

_static_dir = os.path.join(ddtcv.__path__[0], "static")
_default_onnx_model_fp = os.path.join(_static_dir, "model/angle_1_rec_en_number_lite/angle_1_rec_en_number_lite.onnx")
_default_character_dict_fp = os.path.join(_static_dir, "model/angle_1_rec_en_number_lite/angle_dict.txt")
_default_wind_rec_model = ONNXModel(_default_onnx_model_fp, _default_character_dict_fp)
default_x_slice = slice(555, 576)
default_y_slice = slice(29, 73)


def Angle(image: np.ndarray, rec_model: ONNXModel = _default_wind_rec_model, x_slice: slice = default_x_slice,
          y_slice: slice = default_y_slice) -> int:
    x = image[x_slice, y_slice]
    res = rec_angle(x, rec_model)
    return res


def rec_angle(angle_image: np.ndarray, rec_model: ONNXModel = _default_wind_rec_model) -> int:
    return int(rec_model.predict(angle_image))


def save_angle_image(filename: str, image: np.ndarray, x_slice: slice = default_x_slice,
                     y_slice: slice = default_y_slice) -> None:
    cv.imwrite(filename, image[x_slice, y_slice])



"""
create_time: 2023/2/4 14:54
author: TsangHans
"""
from unittest import TestCase
from ddtcv import Angle, save_angle_image
import cv2 as cv


class Test(TestCase):
    def test_angle(self):
        x = cv.imread("image/img2.png")
        res = Angle(x)
        assert res == 49

    def test_save_angle_image(self):
        x = cv.imread("image/img2.png")
        save_angle_image("image/img2_angle.png", x)
